@@ -385,14 +385,7 @@ class Transaction implements AutoCloseable {
 	public void close() throws InterruptedException, ExecutionException {
 		if (isClosed.compareAndSet(false, true)) {
 			try {
-				// Stop new tasks being submitted to the executor from now
-				Future<Boolean> result = submitAndShutdown(() -> {
-					txnConnection.close();
-					return true;
-				});
-				// Shutdown is atomic with the close operation above, so just need to block for it to complete before
-				// returning
-				getFromFuture(result);
+				txnConnection.close();
 			} finally {
 				try {
 					if (!executor.isTerminated()) {
@@ -417,7 +410,6 @@ class Transaction implements AutoCloseable {
 		Future<RepositoryConnection> result = submit(() -> {
 			RepositoryConnection conn = rep.getConnection();
 			ParserConfig config = conn.getParserConfig();
-			config.set(BasicParserSettings.PRESERVE_BNODE_IDS, true);
 			config.addNonFatalError(BasicParserSettings.VERIFY_DATATYPE_VALUES);
 			config.addNonFatalError(BasicParserSettings.VERIFY_LANGUAGE_TAGS);
 
